@@ -45,7 +45,30 @@ class Object(dict):
         return self.__getitem__(value)
 
 
-obj = Object({"t": 12}, a=10, b=15)
-obj.default = "kko"
-obj.extend({"e": 10})
+class Chain:
+    def __init__(self, llist=None):
+        if llist is None:
+            llist = []
+        self.__list = llist
 
+        for i in range(len(self.__list) - 1):
+            self.__dict__[self.__list[i]] = self.__list[i + 1]
+
+        self.__dict__[self.__list[-1]] = self.__list[0]
+
+    def __getitem__(self, item):
+        return self.__dict__[item]
+
+    def __update(self):
+        for i in range(len(self.__list) - 1):
+            self.__dict__[self.__list[i]] = self.__list[i + 1]
+
+        self.__dict__[self.__list[-1]] = self.__list[0]
+
+    def pop(self, index):
+        del self.__dict__[index]
+        self.__list.pop(self.__list.index(index))
+        self.__update()
+
+    def index(self, value):
+        return self.__list[self.__list.index(value) - 1]
